<?php
/*
 * Plugin Name:       Woo Multiprice (EasyToolsWP)
 * Description:       Add multiple prices for WooCommerce products based on quantity.
 * Version:           1.0.1
 * Requires at least: 6.6
 * Author:            EasyToolsWP.com
 * Requires Plugins:  woocommerce
 */

// Security check to prevent direct access
if (!defined('ABSPATH')) {
    exit;
}

// Add a new metabox to the product edit screen
add_action('add_meta_boxes', 'add_multiprice_meta_box');
function add_multiprice_meta_box() {
    add_meta_box(
        'woocommerce-multiprice',
        __('Multiprice', 'woocommerce-multiprice'),
        'multiprice_meta_box_callback',
        'product',
        'side'
    );
}

// Callback function for the metabox
function multiprice_meta_box_callback($post) {
    wp_nonce_field('save_multiprice_data', 'multiprice_meta_box_nonce');

    $values = get_post_meta($post->ID, '_multiprice', true);

    ?>
    <p>
        <label for="multiprice_values"><?php _e('Enter multiprices (quantity|price, e.g., 2|50,3|70)', 'woocommerce-multiprice'); ?></label>
        <textarea name="multiprice_values" id="multiprice_values" rows="4" style="width: 100%;"><?php echo esc_textarea($values); ?></textarea>
    </p>
    <?php
}

// Save multiprices when the product is saved
add_action('save_post', 'save_multiprice_data');
function save_multiprice_data($post_id) {
    if (!isset($_POST['multiprice_meta_box_nonce']) || !wp_verify_nonce($_POST['multiprice_meta_box_nonce'], 'save_multiprice_data')) {
        return;
    }

    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }

    if (isset($_POST['post_type']) && 'product' === $_POST['post_type']) {
        if (!current_user_can('edit_post', $post_id)) {
            return;
        }
    }

    if (!isset($_POST['multiprice_values'])) {
        return;
    }

    $multiprice_values = sanitize_textarea_field($_POST['multiprice_values']);
    update_post_meta($post_id, '_multiprice', $multiprice_values);
}

// Display multiprices below the product price on the product page
add_action('woocommerce_single_product_summary', 'display_multiprice', 25);
function display_multiprice() {
    global $post;

    $values = get_post_meta($post->ID, '_multiprice', true);

    if ($values) {
        echo '<div class="woocommerce-multiprice">';
        echo '<h4>' . __('Mængderabat', 'woocommerce-multiprice') . '</h4>';
        echo '<ul>';
        $prices = explode(',', $values);
        foreach ($prices as $price) {
            list($qty, $price) = explode('|', $price);
            echo '<li>' . sprintf(__('Køb %s for %s pr. stk.', 'woocommerce-multiprice'), $qty, wc_price($price)) . '</li>';
        }
        echo '</ul>';
        echo '</div>';
    }
}

// Apply discount price in the cart
add_action('woocommerce_before_calculate_totals', 'apply_multiprice_discount');
function apply_multiprice_discount($cart) {
    if (is_admin() && !defined('DOING_AJAX')) {
        return;
    }

    foreach ($cart->get_cart() as $cart_item) {
        $product_id = $cart_item['product_id'];
        $values = get_post_meta($product_id, '_multiprice', true);

        if ($values) {
            $prices = explode(',', $values);
            $quantities_prices = [];
            foreach ($prices as $price) {
                list($qty, $price) = explode('|', $price);
                $quantities_prices[intval($qty)] = floatval($price);
            }

            krsort($quantities_prices);

            foreach ($quantities_prices as $qty => $price) {
                if ($cart_item['quantity'] >= $qty) {
                    $cart_item['data']->set_price($price);
                    break;
                }
            }
        }
    }
}
